@@ -940,7 +940,7 @@ class FigureCanvasQT(QtWidgets.QWidget, FigureCanvasBase):
         # bit twiddling to pick out modifier keys from event_mods bitmask,
         # if event_key is a MODIFIER, it should not be duplicated in mods
         mods = [SPECIAL_KEYS[key].replace('control', 'ctrl')
-                for mod, key in MODIFIER_KEYS
+                for _, mod, key in MODIFIER_KEYS
                 if event_key != key and event_mods & mod]
         try:
             # for certain keys (enter, left, backspace, etc) use a word for the
